#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IF_ELSE_ALLBITS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IF_ELSE_ALLBITS_HPP_INCLUDED

#include <boost/simd/boolean/include/functions/if_else_allbits.hpp>

#endif
